@@ -1,17 +1,20 @@
+from __future__ import unicode_literals
+
 import random
 import string
 
 from django.test import TestCase
-from django.test.utils import override_settings
 from httmock import all_requests, HTTMock
 
+from django_seo_js.tests.utils import override_settings
 from django_seo_js.backends import PrerenderHosted
 
-MOCK_RESPONSE = "<html><body><h1>Hello, World!</h1></body></html>"
+MOCK_RESPONSE = b"<html><body><h1>Hello, World!</h1></body></html>"
 MOCK_RESPONSE_HEADERS = {"foo": "bar"}
 MOCK_RECACHE_RESPONSE = "OK"
 MOCK_RECACHE_HEADERS = {"ibbity": "ack"}
-MOCK_GIANT_RESPONSE = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(200000))
+_ascii = string.ascii_uppercase + string.digits
+MOCK_GIANT_RESPONSE = ''.join(random.choice(_ascii) for _ in range(200000)).encode('ascii')
 
 
 @all_requests
@@ -42,11 +45,11 @@ def mock_prerender_giant_response(url, request):
 
 class PrerenderHostedTestURLs(TestCase):
 
-    @override_settings(SEO_JS_PRERENDER_RECACHE_URL="http://example.com")
+    @override_settings(PRERENDER_RECACHE_URL="http://example.com")
     def test_init_throws_exception_if_render_url_is_missing(self):
         self.assertRaises(ValueError, PrerenderHosted)
 
-    @override_settings(SEO_JS_PRERENDER_URL="http://example.com")
+    @override_settings(PRERENDER_URL="http://example.com")
     def test_init_throws_exception_if_recache_url_is_missing(self):
         self.assertRaises(ValueError, PrerenderHosted)
 
@@ -54,8 +57,8 @@ class PrerenderHostedTestURLs(TestCase):
         self.assertRaises(ValueError, PrerenderHosted)
 
     @override_settings(
-        SEO_JS_PRERENDER_RECACHE_URL="http://example.com/recache",
-        SEO_JS_PRERENDER_URL="http://example.com"
+        PRERENDER_RECACHE_URL="http://example.com/recache",
+        PRERENDER_URL="http://example.com"
     )
     def test_no_exception_if_both_are_provided(self):
         self.backend = PrerenderHosted()
@@ -64,8 +67,8 @@ class PrerenderHostedTestURLs(TestCase):
 class PrerenderHostedTestMethods(TestCase):
 
     @override_settings(
-        SEO_JS_PRERENDER_RECACHE_URL="http://example.com/recache",
-        SEO_JS_PRERENDER_URL="http://example.com"
+        PRERENDER_RECACHE_URL="http://example.com/recache",
+        PRERENDER_URL="http://example.com"
     )
     def setUp(self):
         self.backend = PrerenderHosted()
@@ -86,16 +89,11 @@ class PrerenderHostedTestMethods(TestCase):
             resp = self.backend.get_response_for_url("http://www.example.com")
             self.assertEqual(MOCK_GIANT_RESPONSE, resp.content)
 
-    def test_update_url_with_url_only(self):
+    def test_update_url_with_url(self):
         with HTTMock(mock_prerender_recache_response):
             resp = self.backend.update_url(url="http://www.example.com")
             self.assertEqual(resp, True)
 
-    def test_update_url_with_regex_only(self):
-        with HTTMock(mock_prerender_recache_response):
-            resp = self.backend.update_url(regex="http://www.example.com/*")
-            self.assertEqual(resp, True)
-
-    def test_update_url_missing_url_and_regex(self):
+    def test_update_url_missing_url(self):
         with HTTMock(mock_prerender_recache_response):
             self.assertRaises(ValueError, self.backend.update_url)
