@@ -14,13 +14,15 @@ DATABASES = {
 }
 
 SECRET_KEY = 'alksjdf93jqpijsdaklfjq;3lejqklejlakefjas'
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-)
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'APP_DIRS': True,
+    },
+]
 
 MIDDLEWARE_CLASSES = (
-    'django_seo_js.middleware.HashBangMiddleware',
+    'django_seo_js.middleware.EscapedFragmentMiddleware',
     'django_seo_js.middleware.UserAgentMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
